@@ -24,7 +24,7 @@ except ImportError:
     mysql = None
 
 
-__version__ = "0.7.2"
+__version__ = "0.7.7"
 __all__ = [
     "Association",
     "Field",
@@ -70,6 +70,11 @@ _sql_ops = {
     "gt": ">",
     "ge": ">=",
     "ne": "<>",
+    "add": "+",
+    "sub": "-",
+    "mul": "*",
+    "truediv": "/",
+    "mod": "%",
 }
 
 
@@ -511,8 +516,8 @@ class Schema(metaclass=SchemaMetaclass):
         changeset = cls._validate(updating, changeset)
 
         # A user specified validation function
-        validate_func = getattr(cls, "validate", lambda x: x)
-        changeset = validate_func(changeset)
+        validate_func = getattr(cls, "validate", lambda _, x: x)
+        changeset = validate_func(updating, changeset)
 
         return changeset
 
@@ -521,7 +526,7 @@ class Schema(metaclass=SchemaMetaclass):
         # BIG HACK OH NO
         if isinstance(name, Field):
             name = name.name
-        return getattr(cls, name)
+        return getattr(cls, name, None)
 
     @classmethod
     def _is_association(cls, name):
